==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/CascadeOnUpdate.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.foundation;

namespace com.db4o.test {
    public class CascadeOnUpdate {

        Object child;

        public void configure() {
            Db4o.configure().objectClass(this).cascadeOnUpdate(true);
        }

        public void store() {
            Tester.deleteAllInstances(this);
            Tester.deleteAllInstances(new Atom());
            CascadeOnUpdate cou = new CascadeOnUpdate();
            cou.child = new Atom(new Atom("storedChild"), "stored");
            Tester.store(cou);
            Tester.commit();
        }

        class CheckUpdate1 : Visitor4{
            public void visit(Object obj) {
                CascadeOnUpdate cou = (CascadeOnUpdate) obj;
                ((Atom)cou.child).name = "updated";
                ((Atom)cou.child).child.name = "updated";
                Tester.store(cou);
            }
        }

        class CheckUpdate2 : Visitor4{
            public void visit(Object obj) {
                CascadeOnUpdate cou = (CascadeOnUpdate) obj;
                Atom atom = (Atom)cou.child;
                Tester.ensure(atom.name.Equals("updated"));
                Tester.ensure( ! atom.child.name.Equals("updated"));
            }
        }


        public void test() {
            Tester.forEach(this, new CheckUpdate1());
            Tester.reOpen();
            Tester.forEach(this, new CheckUpdate2());
        }
    }

}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/CascadeOnUpdate.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using com.db4o.foundation;

namespace com.db4o.test {
    public class CascadeOnUpdate {

        Object child;

        public void Configure() {
            Db4o.Configure().ObjectClass(this).CascadeOnUpdate(true);
        }

        public void Store() {
            Tester.DeleteAllInstances(this);
            Tester.DeleteAllInstances(new Atom());
            CascadeOnUpdate cou = new CascadeOnUpdate();
            cou.child = new Atom(new Atom("storedChild"), "stored");
            Tester.Store(cou);
            Tester.Commit();
        }

        class CheckUpdate1 : Visitor4{
            public void Visit(Object obj) {
                CascadeOnUpdate cou = (CascadeOnUpdate) obj;
                ((Atom)cou.child).name = "updated";
                ((Atom)cou.child).child.name = "updated";
                Tester.Store(cou);
            }
        }

        class CheckUpdate2 : Visitor4{
            public void Visit(Object obj) {
                CascadeOnUpdate cou = (CascadeOnUpdate) obj;
                Atom atom = (Atom)cou.child;
                Tester.Ensure(atom.name.Equals("updated"));
                Tester.Ensure( ! atom.child.name.Equals("updated"));
            }
        }


        public void Test() {
            Tester.ForEach(this, new CheckUpdate1());
            Tester.ReOpen();
            Tester.ForEach(this, new CheckUpdate2());
        }
    }

}
